# histmp

[![builds.sr.ht status](https://builds.sr.ht/~ddavis/histmp.svg)](https://builds.sr.ht/~ddavis/histmp?)
![](https://img.shields.io/pypi/pyversions/pygram11.svg?colorB=blue&style=flat)
[![PyPI](https://img.shields.io/pypi/v/histmp?color=486b87)](https://pypi.org/project/histmp/)


A Python 3 module for calculating histograms with blazing speed.

This software is currently alpha quality, but it is tested. The public
API is unstable between 0.0.x releases.
